@@ -20,6 +20,7 @@
 #include <QDir>
 #include <KUrl>
 #include <KRandomSequence>
+#include <KDebug>
 
 #include "picture.h"
 #include "slideshow.h"
@@ -39,13 +40,13 @@ SlideShow::~SlideShow()
 
 void SlideShow::setRandom(bool tmp)
 {
-	useRandom = tmp;
+    useRandom = tmp;
 }
 
 void SlideShow::setDirs(const QStringList &slideShowPath, bool recursive)
 {
     m_pictures.clear();
-    foreach (const QString &path, slideShowPath) {
+    foreach(const QString &path, slideShowPath) {
         if (recursive) {
             addRecursiveDir(path);
         } else {
@@ -54,7 +55,7 @@ void SlideShow::setDirs(const QStringList &slideShowPath, bool recursive)
     }
 }
 
-void SlideShow::setImage(const QString &imagePath) 
+void SlideShow::setImage(const QString &imagePath)
 {
     m_pictures.clear();
     addImage(imagePath);
@@ -63,7 +64,7 @@ void SlideShow::setImage(const QString &imagePath)
 void SlideShow::addImage(const QString &imagePath)
 {
     if (!m_pictures.contains(imagePath)) {
-	    m_pictures.append(imagePath);
+        m_pictures.append(imagePath);
     }
 }
 
@@ -73,17 +74,17 @@ void SlideShow::addDir(const QString &path)
 
     dir.setNameFilters(m_filters);
     if (dir.entryList().isEmpty())  {
-	//TODO remove the path from the list
-	return;
+        //TODO remove the path from the list
+        return;
     }
-    foreach (const QString &imageFile, dir.entryList(QDir::Files)) {
-	    addImage(path + "/" + imageFile);
+    foreach(const QString &imageFile, dir.entryList(QDir::Files)) {
+        addImage(path + '/' + imageFile);
     }
     KRandomSequence randomSequence;
     indexList.clear();
     //get the number of sounds then shuffle it: each number will be taken once then the sequence will come back
-    for (uint j = 0; j < m_pictures.count(); j++) 
-	indexList.append(j);
+    for (int j = 0; j < m_pictures.count(); j++)
+        indexList.append(j);
     randomSequence.randomize(indexList);
 }
 
@@ -92,33 +93,38 @@ void SlideShow::addRecursiveDir(const QString &path)
     addDir(path);
     QDir dir(path);
 
-    foreach (const QString &subDir, dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot)) {
-        addRecursiveDir(path + "/" + subDir);
+    foreach(const QString &subDir, dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot)) {
+        addRecursiveDir(path + '/' + subDir);
     }
 }
 
-QImage SlideShow::getImage() 
+QImage SlideShow::getImage()
 {
-    KUrl url = getUrl();
+    currentUrl = getUrl();
     Picture myPicture;
-    return myPicture.setPicture(url);
+    return myPicture.setPicture(currentUrl);
 }
 
-KUrl SlideShow::getUrl() 
+KUrl SlideShow::getUrl()
 {
     if (!m_pictures.isEmpty()) {
 
-	    int index = -1;
-	    if(useRandom) {
-		    randomInt++;
-		    index = indexList[randomInt%m_pictures.count()];
-		    kDebug() << "Random was selected and the index was: " << index << " out of " << m_pictures.count() << " images" << endl;
-	    } else {
-		    index = m_slideNumber++ % m_pictures.count();
-	    }
+        int index = -1;
+        if (useRandom) {
+            randomInt++;
+            index = indexList[randomInt%m_pictures.count()];
+            //kDebug() << "Random was selected and the index was: " << index << " out of " << m_pictures.count() << " images" << endl;
+        } else {
+            index = m_slideNumber++ % m_pictures.count();
+        }
 
-	    return KUrl(m_pictures.at(index));
+        return KUrl(m_pictures.at(index));
     } else {
-	    return KUrl("Default");
+        return KUrl("Default");
     }
 }
+
+KUrl SlideShow::getCurrentUrl()
+{
+    return currentUrl;
+}
