@@ -1,5 +1,6 @@
 /*
  *   Copyright 2007,2008 by Alex Merry <alex.merry@kdemail.net>
+ *   Copyright 2008 by Tony Murray <murraytony@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,6 +24,7 @@
 #include <plasma/applet.h>
 #include <plasma/dataengine.h>
 #include <plasma/service.h>
+#include <Plasma/ToolTipManager>
 
 #include <QPixmap>
 
@@ -68,8 +70,6 @@ signals:
     void controllerChanged(Plasma::Service* controller);
     void metadataChanged(const QMap<QString,QString>& metadata);
     void coverChanged(const QPixmap& picture);
-    void volumeChanged(int volumePercent);
-    void positionChanged(int position);
     void lengthChanged(int length);
 
 public slots:
@@ -77,6 +77,7 @@ public slots:
                      const Plasma::DataEngine::Data &data);
     void playerAdded(const QString &name);
     void playerRemoved(const QString &name);
+    void toolTipAboutToShow();
 
 private slots:
     void play();
@@ -91,6 +92,7 @@ private:
     void findPlayer();
     void layoutPlanar();
     void layoutHorizontal();
+    void updatePositionSlider(int position);
 
     QString m_watchingPlayer;
     Plasma::Service* m_controller;
@@ -105,7 +107,8 @@ private:
 
     qreal m_volume;
     int m_length;
-    QString m_track;
+    QString m_artist;
+    QString m_title;
     QPixmap m_artwork;
 
     InfoPanel* m_textPanel;
